.. _contributor-guide-index:

.. TODO: Link to the ARTKIT contributor guide

Contributing
============

Ways to Contribute
------------------

There are many ways to contribute, including:

- Create issues for bugs or feature requests
- Address an open issue
- Add or improve unit tests
- Create tutorials
- Improve documentation

We especially encourage contributions that enhance our documentation.

For major contributions, please reach out to the ARTKIT team in advance
(ARTKIT@bcg.com).

Please refer to the
`ARTKIT contributor guide <https://artkit.bcg.com/contributor-guide>`_ for more
detailed information on how to contribute to this project. All instructions that
refer to the ARTKIT repository generally also apply to this *fluxus* repository.
